dygoraphs

package module
v0.0.0-...-a8c1102 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 28, 2016 License: MIT Imports: 3 Imported by: 0

README

Dygoraphs

Dygoraphs is a very simple go library interface to the dygraphs javascript library. It aims to make it easy to generate interactive plots from go.

See the example directory for some examples.

Go Report Card

Documentation

Index

Constants

const Script = `` /* 125484-byte string literal not displayed */

Script contains the dygraphs.js source code.

Variables

This section is empty.

Functions

This section is empty.

Types

type Graph

type Graph struct {
	ID      string
	Style   map[string]string
	Options map[string]string
}

Graph defines a single graph object.

func NewGraph

func NewGraph() *Graph

NewGraph creates a new Graph object.

func (*Graph) Div

func (g *Graph) Div() string

Div creates a graph <div> element to insert into a web page.

func (*Graph) DumpOptions

func (g *Graph) DumpOptions() string

DumpOptions dumps the graph options as JSON.

func (*Graph) DumpStyle

func (g *Graph) DumpStyle() string

DumpStyle dumps the graph style options as JSON.

func (*Graph) EscCSV

func (g *Graph) EscCSV(csv string) string

EscCSV escapes a csv string for inclusion into HTML.

func (*Graph) PlotCSV

func (g *Graph) PlotCSV(csv string) string

PlotCSV creates a dygoraphs plot from CSV data.

func (*Graph) SetOption

func (g *Graph) SetOption(name, value string)

SetOption sets a graph option as a name/value pair.

func (*Graph) SetStyle

func (g *Graph) SetStyle(name, value string)

SetStyle specifies a CSS style attribute to set.

Directories

Path Synopsis

Jump to